@@ -1,6 +1,6 @@
 import os
 import sys
-import functools
+from functools import lru_cache
 from typing import *
 
 from . import protocols
@@ -49,6 +49,19 @@ def install(*options, jar_path:str=CLASS_PATH):
     jnius_config.set_classpath(jar_path)
 
 
+@lru_cache(maxsize=1)
+def load_autoclass():
+    from jnius import autoclass
+
+    return autoclass('java.util.ArrayList'), \
+        autoclass('vn.corenlp.wordsegmenter.Vocabulary'), \
+        autoclass('vn.pipeline.LexicalInitializer'), \
+        autoclass('vn.corenlp.wordsegmenter.WordSegmenter'). \
+        autoclass('vn.corenlp.postagger.PosTagger'), \
+        autoclass('vn.corenlp.ner.NerRecognizer'), \
+        autoclass('vn.corenlp.parser.DependencyParser'), \
+        autoclass('vn.pipeline.VnCoreNLP')
+
 
 class Package:
     ArrayList:Any = None
@@ -62,19 +75,7 @@ class Package:
 
     @classmethod
     def load_class(cls):
-        from jnius import autoclass
-
-        cls.ArrayList = autoclass('java.util.ArrayList')
-        cls.Vocabulary = autoclass('vn.corenlp.wordsegmenter.Vocabulary')
-        cls.LexicalInitializer = autoclass('vn.pipeline.LexicalInitializer')
-
-        cls.WordSegmenter = autoclass('vn.corenlp.wordsegmenter.WordSegmenter')
-        cls.PosTagger = autoclass('vn.corenlp.postagger.PosTagger')
-        cls.NerRecognizer = autoclass('vn.corenlp.ner.NerRecognizer')
-        cls.DependencyParser = autoclass('vn.corenlp.parser.DependencyParser')
-
-        cls.VnCoreNLP = autoclass('vn.pipeline.VnCoreNLP')
-
+        cls.ArrayList, cls.Vocabulary, cls.LexicalInitializer, cls.WordSegmenter, cls.PosTagger, cls.NerRecognizer, cls.DependencyParser, cls.VnCoreNLP = load_autoclass()
 
 class Pipeline:
 
@@ -145,7 +146,7 @@ class Pipeline:
             dep_parser = Package.DependencyParser(os.path.join(model_dir, dep), lexica)
             self.instance.setDependencyParser(dep_parser)
 
-    @functools.lru_cache(maxsize=256)
+    @lru_cache(maxsize=256)
     def annotate_doc(self, doc:str) -> Doc:
         doc = self.instance.annotateDoc(doc)
         return [
@@ -155,7 +156,7 @@ class Pipeline:
             ] for sentence in doc
         ]
 
-    @functools.lru_cache(maxsize=256)
+    @lru_cache(maxsize=256)
     def __annotate_docs(self, docs:Tuple[str, ...]) -> List[Doc]:
         docs_array = Package.ArrayList()
         for doc in docs:
